@@ -18,6 +18,7 @@ import tempfile
 import threading
 import queue
 import re
+from pathlib import Path
 
 def write2path(lines,path='',encoding='utf-8',method='lines',append='w',wrap=True):
     """ 写入数组到本地文件
@@ -233,6 +234,22 @@ def listDir(rootDir,only_file=False,only_folder=False,recursive=False,sort=True)
     else:
         return list_filepath
 
+def globInDir(rootDir,search_regular):
+    """rootDir搜索目录  search_regular搜索关键字 **代表所有目录 *代表所有文件和目录"""
+    list_filepath = []
+    for filename in Path(rootDir).rglob(search_regular):
+        list_filepath.append(str(filename))
+    list_filepath = [f for f in list_filepath if '.DS_Store' not in f]
+    return list_filepath
+
+def globFile(search_regular,recursive=True):
+    """search_regular搜索关键字 **代表所有目录 *代表所有文件和目录
+       /Volumes/Data/PycharmProjects/algorithms/datasets/**/*.jpg
+    """
+    list_filepath = glob.glob(search_regular,recursive=recursive)
+    list_filepath = [f for f in list_filepath if '.DS_Store' not in f]
+    return list_filepath
+
 def makedir(dir_path,delete_exists=False):
     """ 创建文件夹 """
     if os.path.exists(dir_path):
@@ -324,6 +341,21 @@ def func_time(func):
     end_time= time.time()
     print(f'{func.__name__} 耗时:{int(end_time-begin_time)}')
 
+def run_multi_task_in_large(all_items, user_func, cpu_num=os.cpu_count(), by_order=False):
+    result = []
+    if len(all_items) > 32000:
+        for i in range(0, len(all_items), 32000):
+            if by_order:
+                result.extend(list(sorted(run_multi_task_in_order(all_items[i: i + 32000], user_func, cpu_num=cpu_num).items(),key=lambda f:f[0])))
+            else:
+                result.extend(run_multi_task(all_items[i: i + 32000], user_func, cpu_num=cpu_num))
+    else:
+        if by_order:
+            result.extend(run_multi_task_in_order(all_items, user_func, cpu_num=cpu_num))
+        else:
+            result.extend(run_multi_task(all_items, user_func, cpu_num=cpu_num))
+    return result
+
 def run_multi_task(all_items, user_func, cpu_num=os.cpu_count()):
     """ 多进程执行方法 """
     print(f'检测到全部:{len(all_items)}个')
@@ -604,6 +636,19 @@ def split_path(file_path):
     folder_path=os.path.dirname(file_path)
     return folder_path,file_name
 
+def dirname(file_path,depth=1,root=None):
+    folder_path, file_name = os.path.split(file_path)
+    if root:
+        for i in range(10):
+            folder_path,file_name = os.path.split(folder_path)
+            if folder_path.endswith(root):
+                return folder_path
+    else:
+        if depth>1:
+            for i in range(depth-1):
+                folder_path=os.path.dirname(folder_path)
+    return folder_path
+
 def search_by_regular(pattern,content):
     regex = re.compile(pattern)
     return regex.findall(content)
